pub struct ParsedContractClass {
pub program: Program,
pub entry_points_by_type: HashMap<EntryPointType, Vec<ContractEntryPoint>>,
pub abi: Option<AbiType>,
}Fields
program: Programentry_points_by_type: HashMap<EntryPointType, Vec<ContractEntryPoint>>abi: Option<AbiType>Trait Implementations
sourceimpl Clone for ParsedContractClass
impl Clone for ParsedContractClass
sourcefn clone(&self) -> ParsedContractClass
fn clone(&self) -> ParsedContractClass
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for ParsedContractClass
impl Debug for ParsedContractClass
sourceimpl<'de> Deserialize<'de> for ParsedContractClass
impl<'de> Deserialize<'de> for ParsedContractClass
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<ParsedContractClass> for ParsedContractClass
impl PartialEq<ParsedContractClass> for ParsedContractClass
sourcefn eq(&self, other: &ParsedContractClass) -> bool
fn eq(&self, other: &ParsedContractClass) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl TryFrom<&PathBuf> for ParsedContractClass
impl TryFrom<&PathBuf> for ParsedContractClass
sourceimpl TryFrom<&str> for ParsedContractClass
impl TryFrom<&str> for ParsedContractClass
type Error = ProgramError
type Error = ProgramError
The type returned in the event of a conversion error.
sourceimpl TryFrom<ContractClass> for ParsedContractClass
impl TryFrom<ContractClass> for ParsedContractClass
type Error = ProgramError
type Error = ProgramError
The type returned in the event of a conversion error.
sourceimpl TryFrom<PathBuf> for ParsedContractClass
impl TryFrom<PathBuf> for ParsedContractClass
impl Eq for ParsedContractClass
impl StructuralEq for ParsedContractClass
impl StructuralPartialEq for ParsedContractClass